pub struct ZstdArray { /* private fields */ }Implementations
Sourceimpl ZstdArray
impl ZstdArray
pub fn new( dictionary: Option<ByteBuffer>, frames: Vec<ByteBuffer>, dtype: DType, metadata: ZstdMetadata, n_rows: usize, validity: Validity, ) -> Self
Sourcepub fn from_primitive(
parray: &PrimitiveArray,
level: i32,
values_per_frame: usize,
) -> VortexResult<Self>
pub fn from_primitive( parray: &PrimitiveArray, level: i32, values_per_frame: usize, ) -> VortexResult<Self>
Creates a ZstdArray from a primitive array.
Arguments
parray- The primitive array to compresslevel- Zstd compression level (0 = default, negative = fast, positive = better compression)values_per_frame- Number of values per frame (0 = single frame)
Sourcepub fn from_primitive_without_dict(
parray: &PrimitiveArray,
level: i32,
values_per_frame: usize,
) -> VortexResult<Self>
pub fn from_primitive_without_dict( parray: &PrimitiveArray, level: i32, values_per_frame: usize, ) -> VortexResult<Self>
Creates a ZstdArray from a primitive array without using a dictionary.
This is useful when the compressed data will be decompressed by systems that don’t support ZSTD dictionaries (e.g., nvCOMP on GPU).
Note: Without a dictionary, each frame is compressed independently. Dictionaries are trained from sample data from previously seen frames, to improve compression ratio.
Arguments
parray- The primitive array to compresslevel- Zstd compression level (0 = default, negative = fast, positive = better compression)values_per_frame- Number of values per frame (0 = single frame)
Sourcepub fn from_var_bin_view(
vbv: &VarBinViewArray,
level: i32,
values_per_frame: usize,
) -> VortexResult<Self>
pub fn from_var_bin_view( vbv: &VarBinViewArray, level: i32, values_per_frame: usize, ) -> VortexResult<Self>
Creates a ZstdArray from a VarBinView array.
Arguments
vbv- The VarBinView array to compresslevel- Zstd compression level (0 = default, negative = fast, positive = better compression)values_per_frame- Number of values per frame (0 = single frame)
Sourcepub fn from_var_bin_view_without_dict(
vbv: &VarBinViewArray,
level: i32,
values_per_frame: usize,
) -> VortexResult<Self>
pub fn from_var_bin_view_without_dict( vbv: &VarBinViewArray, level: i32, values_per_frame: usize, ) -> VortexResult<Self>
Creates a ZstdArray from a VarBinView array without using a dictionary.
This is useful when the compressed data will be decompressed by systems that don’t support ZSTD dictionaries (e.g., nvCOMP on GPU).
Note: Without a dictionary, each frame is compressed independently. Dictionaries are trained from sample data from previously seen frames, to improve compression ratio.
Arguments
vbv- The VarBinView array to compresslevel- Zstd compression level (0 = default, negative = fast, positive = better compression)values_per_frame- Number of values per frame (0 = single frame)
pub fn from_canonical( canonical: &Canonical, level: i32, values_per_frame: usize, ) -> VortexResult<Option<Self>>
pub fn from_array( array: ArrayRef, level: i32, values_per_frame: usize, ) -> VortexResult<Self>
pub fn decompress(&self) -> VortexResult<ArrayRef>
Sourcepub fn into_parts(self) -> ZstdArrayParts
pub fn into_parts(self) -> ZstdArrayParts
Consumes the array and returns its parts.