pub struct ZstdBuffersData { /* private fields */ }Expand description
An encoding that ZSTD-compresses the buffers of any wrapped array.
Unlike ZstdArray, which interleaves string lengths with content bytes,
ZstdBuffersArray compresses each buffer independently. This enables zero-conversion
GPU decompression since the original buffer layout is preserved after decompression.
Implementations
Sourceimpl ZstdBuffersData
impl ZstdBuffersData
Sourcepub fn decode_plan(&self) -> VortexResult<ZstdBuffersDecodePlan>
pub fn decode_plan(&self) -> VortexResult<ZstdBuffersDecodePlan>
Build a decode plan for external or device decompression.